==> msn-proxy-0.5.tar.gz: msn-proxy/php/index.php <==
<?php
/*
 * Copyright (c) 2004, 2005, 2006, 2007 Luiz Otavio O Souza <loos.br@gmail.com>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

/* 
 * $Id: index.php,v 1.43 2007/09/03 14:18:40 luiz Exp $
 */

// A linha abaixo elimina mensagem de erro nos logs do php.
(isset($_REQUEST['showoffline'])) ? $showoffline="on" : $showoffline="off";
// by Eric Anderson Qua Ago 22 10:57:35 BRT 2007

    require('default.array.option.inc.php');
    require('default.array.status.inc.php');
    require('default.array.cmd.inc.php');
    require('header.inc.php');
    require('mysql.inc.php');

    $sql  = "SELECT connect, save_msg, save_contacts, commands ";
    $sql .= "FROM defaults LIMIT 1";
    $rs = mysql_query($sql, $mysql) or die('falha no sql');
    $DENYMASK = 0;
    if (mysql_num_rows($rs) > 0) {
	$row = mysql_fetch_array($rs) or die("falha no result do sql");
	$DENYMASK = intval($row['commands']);
	if (strcasecmp($row['connect'], "no") == 0)
	    $DENYMASK |= $arrayCMD['CONNECT'];
	if (strcasecmp($row['save_msg'], "no") == 0)
	    $DENYMASK |= $arrayCMD['SAVE_MSG'];
	if (strcasecmp($row['save_contacts'], "no") == 0)
	    $DENYMASK |= $arrayCMD['SAVE_CONTACTS'];
    }

    $sqloffl  = "SELECT email, display_name, status, ";
    $sqloffl .= "last_seen, last_addr, connect, ";
    $sqloffl .= "save_msg, save_contacts, commands ";
    $sqloffl .= "FROM users WHERE status = 'OFF' ";
    $sqloffl .= "ORDER BY display_name, email";

    $sql  = "SELECT email, display_name, status, ";
    $sql .= "last_seen, last_addr, connect, ";
    $sql .= "save_msg, save_contacts, commands ";
    $sql .= "FROM users WHERE status != 'OFF' ";
    $sql .= "ORDER BY status, display_name, email";

    $rs = mysql_query($sql, $mysql) or die('falha no sql');
    $rsoffl = mysql_query($sqloffl, $mysql) or die('falha no sqloffl');

    $count = mysql_num_rows($rs);
    $countoffl = mysql_num_rows($rsoffl);

    function print_user($row = NULL, $i = 0, $denymask = 0) {

	global $mysql, $arrayCMD, $arrayOption, $arrayStatus;
	if ($row == NULL) return;

        $status = $arrayStatus[$row['status']];

        $sql = "SELECT DISTINCT id, since FROM sb WHERE email = '".$row['email']."'";
        $rs2 = mysql_query($sql, $mysql);
        $sb = mysql_num_rows($rs2);

        $sql  = "SELECT DISTINCT count(*) FROM log WHERE ";
        $sql .= "email = '".$row['email']."' AND (type = 'start' OR type = 'join') ";
        $sql .= "ORDER BY date DESC ";
        $rsChat = mysql_query($sql, $mysql) or die ("SELECT FAIL");
        $rowChat = mysql_fetch_array($rsChat);

	/* check from default denymask */
	$DenyMask = intval($row['commands']);
	if (strcasecmp($row['connect'], "no") == 0)
            $DenyMask |= $arrayCMD[CONNECT];
	if (strcasecmp($row['save_msg'], "no") == 0)
            $DenyMask |= $arrayCMD[SAVE_MSG];
	if (strcasecmp($row['save_contacts'], "no") == 0)
            $DenyMask |= $arrayCMD[SAVE_CONTACTS];

	$DenyBold = ($DenyMask == $denymask) ? 0 : 1;
?>
<table border=0 cellpadding=0 cellspacing=0
	style="border-color: gray; border-style: solid; border-width: 1;">
  <tr><td>
   <table border=0 width=440>
    <tr align="center">
     <td bgcolor="#EBEBEB" width=440 colspan=3>MSN</td>
    </tr>
    <tr>
     <td bgcolor="#EBEBEB" colspan=3>
        <table border=0 cellpadding=0 cellspacing=0>
          <tr>
            <td>
                <img src="imagens/<?php echo $status['img'] ?>"
                alt="<?php echo $status['msg'] ?>" border=0>
            </td>
            <td width="100%">
                <a href="user.php?email=<?php echo $row[0] ?>" title="<?php echo $row[0] ?>"><?php echo $row['display_name'] ?>
                <?php echo ($status['img'] != "online.gif") ?
                        "<font color=\"gray\">(".$status['msg'].")</font>" : "" ?></a>
            </td>
            <td>
<?php
        /* user has any chat ? */
        if (intval($rowChat[0]) > 0) {
?>
                <a href="javascript: popup('chat.php?email=<?php echo $row[0] ?>')"
		title="<?php echo $row[0] ?>"><img src="imagens/send_im.gif" border=0></a>
<?php
        }
?>
          </td>
          </tr>
        </table></td>
    </tr>
    <tr>
     <td bgcolor="#EBEBEB" align=center>ltima conexo</td>
     <td bgcolor="#EBEBEB" align=center>ltimo IP</td>
     <td bgcolor="#EBEBEB" align=center>Excluir / Novo</td>
    </tr>
    <tr>
     <td bgcolor="#EBEBEB" align=center><?php echo $row['last_seen'] ?></td>
     <td bgcolor="#EBEBEB" align=center><?php echo $row['last_addr'] ?></td>
     <td bgcolor="#EBEBEB" align=center><a
        href="javascript: showOptions('user_op_<?php echo $i ?>');
        showOptions('user_op_<?php echo $i + 1 ?>');
        showOptions('user_op_<?php echo $i + 2 ?>');"
	><?php echo $DenyBold ? "<b>" : "" ?>Outras opes<?php echo $DenyBold ? "</b>" : "" ?></a></td>
    </tr>
        <tr id="user_op_<?php echo $i ?>" style="DISPLAY: none;">
          <td bgcolor="#EBEBEB" align=center>Conecta</td>
          <td bgcolor="#EBEBEB" align=center>Salva mensagens</td>
          <td bgcolor="#EBEBEB" align=center>Salva contatos</td>
        </tr>
        <tr id="user_op_<?php echo $i + 1 ?>" style="DISPLAY: none;">
          <td bgcolor="#EBEBEB" align=center>
	    <select name="connect" onchange="javascript: saveSelect('save_user_op.php?user=<?php echo $row['email'] ?>&name=connect', this)">
              <option value="yes" <?php echo ($row['connect'] == "YES") ? "selected" : "" ?>>Sim
              <option value="no" <?php echo ($row['connect'] == "NO") ? "selected" : "" ?>>No
            </select>
          </td>
          <td bgcolor="#EBEBEB" align="center">
	    <select name="save_msg" onchange="javascript: saveSelect('save_user_op.php?user=<?php echo $row['email'] ?>&name=save_msg', this)">
              <option value="yes" <?php echo ($row['save_msg'] == "YES") ? "selected" : "" ?>>Sim
              <option value="no" <?php echo ($row['save_msg'] == "NO") ? "selected" : "" ?>>No
            </select>
          </td>
          <td bgcolor="#EBEBEB" align="center">
	    <select name="save_contacts" onchange="javascript: saveSelect('save_user_op.php?user=<?php echo $row['email'] ?>&name=save_contacts', this)">
              <option value="yes" <?php echo ($row['save_contacts'] == "YES") ? "selected" : "" ?>>Sim
              <option value="no" <?php echo ($row['save_contacts'] == "NO") ? "selected" : "" ?>>No
            </select>
          </td>
        </tr>
        <tr id="user_op_<?php echo $i + 2 ?>" style="DISPLAY: none;">
          <td bgcolor="#EBEBEB" colspan=3 align=center>Outras Opes<br>
                <table border=0 width="100%">
<?php
	$o = 0;
	for(;;) {

	    if (!$arrayOption[$o])
		break;

	    print_option($i, $o, $row['commands'], $row['email']);
	    $o += 2;
	}
?>
                </table>
          </td>
        </tr>
<?php
        if ($sb > 0) {
?>
    <tr>
     <td colspan=5>
      <table border=0 width="100%">
       <tr>
        <td bgcolor="#EBEBEB" align="center" width=440>Chats</td>
       </tr>
<?php
            while (($row2 = mysql_fetch_array($rs2))) {

                $sql  = "SELECT DISTINCT(email), display_name FROM log ";
                $sql .= "WHERE (type = 'join' OR type = 'start') AND ";
                $sql .= "sb_id =". $row2['id'] ." AND ";
                $sql .= "email <> '".$row['email']."' ";
                $rsSB = mysql_query($sql, $mysql);
?>
       <tr>
        <td bgcolor="#EBEBEB">
<?php
                while (($rowSB = mysql_fetch_array($rsSB))) {

                    $sql  = "SELECT * FROM contacts WHERE ";
                    $sql .= "email = '".$row['email']."' AND ";
                    $sql .= "contact_email = '".$rowSB['email']."' ";
                    $rsContact = mysql_query($sql, $mysql);
                    $rowContact = mysql_fetch_array($rsContact);
                    $statusContact = $arrayStatus[$rowContact[contact_status]];
?>

        <table border=0 cellpadding=0 cellspacing=0>
          <tr>
            <td>
                <img src="imagens/<?php echo $statusContact['img'] ?>" alt="<?php echo $statusContact['msg'] ?>" border=0>
            </td>
            <td>
                <a href="javascript: popup2('<?php echo $row2['id'] ?>')" title="<?php echo $rowSB['email'] ?>">
                <?php echo $rowSB['display_name'] ?>
                <?php echo ($statusContact['img'] != "online.gif") ?
                        "<font color=\"gray\">(".$statusContact['msg'].")</font>" : "" ?></a><br>
            </td>
          </tr>
        </table>
<?php
                }
                mysql_free_result($rsSB);
?>
        </td>
       </tr>
<?php
            }
?>
      </table>
     </td>
    </tr>
<?php
        }
?>
   </table>
   </td>
  </tr>
 </table>
<?php
    }

    function print_option( $i, $o, $commands, $email) {

	global $arrayCMD, $arrayOption;

	$c    = $o;
	$desc = $arrayOption[$c]['desc'];
	$name = $arrayOption[$c]['name'];
	$cmd  = $arrayOption[$c]['cmd'];
	$id   = $name ."_". ($i + 2);
?>
		  <tr>
		    <td><input type=checkbox value="<?php echo $name ?>" id="<?php echo $id ?>"
			<?php echo ($commands & $arrayCMD[$cmd]) ? "checked" : "" ?>
<?php
	$link  = "javascript: saveCheckBox('save_user_op.php?user=" . $email . "&name=";
	$link .= $name ."', this)";;
?>
			onclick="<?php echo $link ?>">
		    </td><td width="45%"><label for="<?php echo $id ?>"><?php echo $desc ?></label></td>
<?php
	$c    = $o + 1;
	if ($arrayOption[$c]) {
	    $desc = $arrayOption[$c]['desc'];
	    $name = $arrayOption[$c]['name'];
	    $cmd  = $arrayOption[$c]['cmd'];
	    $id   = $name ."_". ($i + 2);
?>
		    <td><input type=checkbox value="<?php echo $name ?>" id="<?php echo $id ?>"
			<?php echo ($commands & $arrayCMD[$cmd]) ? "checked" : "" ?>
<?php
	$link  = "javascript: saveCheckBox('save_user_op.php?user=" . $email . "&name=";
	$link .= $name ."', this)";
?>
			onclick="<?php echo $link ?>">
		    </td><td width="45%"><label for="<?php echo $id ?>"><?php echo $desc ?></label></td>
		  </tr>
<?php
	} else {
?>
		    <td>&nbsp;</td>
		    <td>&nbsp;</td>
		  </tr>
<?php
	}
    }

    require("ajax.inc.php");
?>

<script language="JavaScript">
<!--

    function popup(url) {
	window.open(url, '', 'height=450,width=550,scrollbars=yes');
    }

    function popup2(sb_id) {
	url = 'view.php?sb_id=' + sb_id;
	window.open(url, '', 'height=450,width=550,scrollbars=yes');
    }

    function showOptions(id) {
	var itm = null;

	if (document.getElementById) {
	    itm = document.getElementById(id);
	} else if (document.all){
	    itm = document.all[id];
	} else if (document.layers){
	    itm = document.layers[id];
	}
        
	if (!itm) {
	    // do nothing
	}
	else if (itm.style) {
	    if (itm.style.display == 'none') { itm.style.display = ''; }
	    else { itm.style.display = 'none'; }
	}
	else { itm.visibility = 'show'; }
    }

//-->
</script>

<body bgcolor="#FFFFFF">

<form action="index.php" method="POST" name="form">
<div align="center">
  <div align=center style="width: 892px; border-color: gray; border-style: solid; border-width: 1;">
	<p><strong>MSN Proxy - Usu&aacute;rios</strong></p>
	<p><a href="conf.php">Configuraes</a></p>
	<p>
<?php
    if ($count == 0) {
?>
	Nenhum usu&aacute;rio conectado<br>
<?php
    } else {
?>
	<?php echo $count ?> Usurio<?php echo ($count > 1) ? "s" : "" ?>
	conectado<?php echo($count > 1) ? "s": "" ?><br>
<?php
    }
    if ($countoffl == 0) {
?>
	Nenhum usu&aacute;rio desconectado<br>
<?php
    } else {
?>
	<?php echo $countoffl ?> Usurio<?php echo ($countoffl > 1) ? "s" : "" ?>
	desconectado<?php echo ($countoffl > 1) ? "s": "" ?><br>
<?php
    }
?>
	</p>
	<p><input type="checkbox" name="showoffline" id="off"
	onclick="form.submit();"
	<?php echo ($showoffline=="on") ? "checked" : "" ?>>
	<label for="off">Mostrar usurios offline</label></p>
</div><br>

<?php
    $i = 1;
    $stop = 0;
    while($stop == 0 && ($row = mysql_fetch_array($rs))) {

?>
<table border=0 width="600">
 <tr>
  <td valign="top" align="center">
<?php
	print_user($row, $i, $DENYMASK);
	$row2 = mysql_fetch_array($rs);
	if ($row2 == NULL) {
?>
  </td>
  <td valign="top" align="center">
	&nbsp;
<?php
	    $stop = 1;
	} else {
?>
  </td>
  <td valign="top" align="center">
<?php
	    $i += 3;
	    print_user($row2, $i, $DENYMASK);
	}
?>
  </td>
 </tr>
</table>
<br>
<?php
	$i += 3;
    }

    if ($showoffline == "on") {
	$stop = 0;
	while($stop == 0 && ($row = mysql_fetch_array($rsoffl))) {

?>
<table border=0 width="600">
 <tr>
  <td valign="top" align="center">
<?php
	    print_user($row, $i, $DENYMASK);
	    $row2 = mysql_fetch_array($rsoffl);
	    if ($row2 == NULL) {
?>
  </td>
  <td valign="top" align="center">
        &nbsp;
<?php
		$stop = 1;
	    } else {
?>
  </td>
  <td valign="top" align="center">
<?php
		$i += 3;
		print_user($row2, $i, $DENYMASK);
	    }
?>
  </td>
 </tr>
</table>
<br>
<?php
	    $i += 3;
	}
    }
?>

</div>
</form>

</body>
</html>
<?php
    mysql_close($mysql);
?>

==> msn-proxy-0.6.tar.gz: msn-proxy/php/index.php <==
<?php
/*
 * Copyright (c) 2004, 2005, 2006, 2007, 2008
 *	Luiz Otavio O Souza <loos.br@gmail.com>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

/* 
 * $Id: index.php,v 1.3 2008/04/23 01:22:32 loos-br Exp $
 */

    require('default.array.option.inc.php');
    require('default.array.status.inc.php');
    require('default.array.cmd.inc.php');
    require('header.inc.php');
    require('mysql.inc.php');

    $sql  = "SELECT connect, save_msg, save_contacts, commands ";
    $sql .= "FROM defaults LIMIT 1";
    $rs = mysql_query($sql, $mysql) or die('falha no sql');
    $DENYMASK = 0;
    if (mysql_num_rows($rs) > 0) {
	$row = mysql_fetch_array($rs) or die("falha no result do sql");
	$DENYMASK = intval($row['commands']);
	if (strcasecmp($row['connect'], "no") == 0)
	    $DENYMASK |= $arrayCMD['CONNECT'];
	if (strcasecmp($row['save_msg'], "no") == 0)
	    $DENYMASK |= $arrayCMD['SAVE_MSG'];
	if (strcasecmp($row['save_contacts'], "no") == 0)
	    $DENYMASK |= $arrayCMD['SAVE_CONTACTS'];
    }

    $sqloffl  = "SELECT email, display_name, status, ";
    $sqloffl .= "last_seen, last_addr, connect, ";
    $sqloffl .= "save_msg, save_contacts, commands ";
    $sqloffl .= "FROM users WHERE status = 'OFF' ";
    $sqloffl .= "ORDER BY display_name, email";

    $sql  = "SELECT email, display_name, status, ";
    $sql .= "last_seen, last_addr, connect, ";
    $sql .= "save_msg, save_contacts, commands ";
    $sql .= "FROM users WHERE status != 'OFF' ";
    $sql .= "ORDER BY status, display_name, email";

    $rs = mysql_query($sql, $mysql) or die('falha no sql');
    $rsoffl = mysql_query($sqloffl, $mysql) or die('falha no sqloffl');

    $count = mysql_num_rows($rs);
    $countoffl = mysql_num_rows($rsoffl);

    require("user.inc.php");
    require("ajax.inc.php");
?>

<script language="JavaScript">
<!--

    function popup(url) {
	window.open(url, '', 'height=450,width=550,scrollbars=yes');
    }

    function popup2(sb_id) {
	url = 'view.php?sb_id=' + sb_id;
	window.open(url, '', 'height=450,width=550,scrollbars=yes');
    }

    function showOptions(id) {
	var itm = null;

	if (document.getElementById) {
	    itm = document.getElementById(id);
	} else if (document.all){
	    itm = document.all[id];
	} else if (document.layers){
	    itm = document.layers[id];
	}
        
	if (!itm) {
	    // do nothing
	}
	else if (itm.style) {
	    if (itm.style.display == 'none') { itm.style.display = ''; }
	    else { itm.style.display = 'none'; }
	}
	else { itm.visibility = 'show'; }
    }

//-->
</script>

<body bgcolor="#FFFFFF">

<form action="index.php" method="POST" name="form">
<input type="hidden" name="force">
<div align="center">
  <div align=center style="width: 892px; border-color: gray; border-style: solid; border-width: 1;">
	<p><strong>MSN Proxy - Usu&aacute;rios</strong></p>
	<p><a href="conf.php">Configuraes</a></p>
	<p>
<?php
    if ($count == 0) {
	echo "Nenhum usu&aacute;rio conectado<br>\n";
    } else {
	echo $count ." Usurio";
	echo ($count > 1) ? "s" : "";
	echo " conectado";
	echo ($count > 1) ? "s": "";
	echo "<br>\n";
    }
    if ($countoffl == 0) {
	echo "Nenhum usu&aacute;rio desconectado<br>\n";
    } else {
	echo $countoffl ." Usurio";
	echo ($countoffl > 1) ? "s" : "";
	echo " desconectado";
	echo ($countoffl > 1) ? "s" : "";
	echo "<br>\n";
    }
?>
	</p>
	<p><input type="checkbox" name="showoffline" id="off"
	onclick="form.force.value='1';form.submit();"
<?php
    $showoffline = "off";
    if ((isset($_REQUEST['showoffline']) && $_REQUEST['showoffline'] === "on" &&
	isset($_REQUEST['force']) && $_REQUEST['force'] === "1") ||
	(!isset($_REQUEST['force']) && isset($_SESSION['showoffline']))) {
	echo " checked ";
	$showoffline = "on";
	if (!isset($_SESSION['showoffline']))
	    $_SESSION["showoffline"] = "on";
    }
    if ($showoffline === "off") {
	if (isset($_SESSION['showoffline']))
	    unset($_SESSION['showoffline']);
    }
?>>
	<label for="off">Mostrar usurios offline</label></p>
</div><br>

<?php
    $i = 1;
    $stop = 0;
    while($stop == 0 && ($row = mysql_fetch_array($rs))) {
?>
<table border=0 width="600">
 <tr>
  <td valign="top" align="center">
<?php
	print_user($row, $i, $DENYMASK);
	$row2 = mysql_fetch_array($rs);
	if ($row2 == NULL) {
?>
  </td>
  <td valign="top" align="center">
	&nbsp;
<?php
	    $stop = 1;
	} else {
?>
  </td>
  <td valign="top" align="center">
<?php
	    $i += 3;
	    print_user($row2, $i, $DENYMASK);
	}
?>
  </td>
 </tr>
</table>
<br>
<?php
	$i += 3;
    }

    if ($showoffline == "on") {
	$stop = 0;
	while($stop == 0 && ($row = mysql_fetch_array($rsoffl))) {

?>
<table border=0 width="600">
 <tr>
  <td valign="top" align="center">
<?php
	    print_user($row, $i, $DENYMASK);
	    $row2 = mysql_fetch_array($rsoffl);
	    if ($row2 == NULL) {
?>
  </td>
  <td valign="top" align="center">
        &nbsp;
<?php
		$stop = 1;
	    } else {
?>
  </td>
  <td valign="top" align="center">
<?php
		$i += 3;
		print_user($row2, $i, $DENYMASK);
	    }
?>
  </td>
 </tr>
</table>
<br>
<?php
	    $i += 3;
	}
    }
?>

</div>
</form>

</body>
</html>
<?php
    mysql_close($mysql);
?>
